@@ -442,18 +442,12 @@ impl<'a, I: Input> Lexer<'a, I> {
     fn read_token_number_sign(&mut self) -> LexResult<Option<Token>> {
         debug_assert!(self.cur().is_some());
 
-        let start = self.input.cur_pos();
-
         if self.input.is_at_start() && self.read_token_interpreter()? {
             return Ok(None);
         }
 
-        if self.syntax.class_private_props() || self.syntax.class_private_methods() {
-            self.input.bump(); // '#'
-            return Ok(Some(Token::Hash));
-        }
-
-        self.error(start, SyntaxError::Hash)?
+        self.input.bump(); // '#'
+        return Ok(Some(Token::Hash));
     }
 
     fn read_token_interpreter(&mut self) -> LexResult<bool> {
